==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/RemoteContentProviderChangeEvent.hpp <==
#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_
#define _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HDL_
#include "com/sun/star/ucb/RemoteContentProviderChangeEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEACTION_HPP_
#include "com/sun/star/ucb/RemoteContentProviderChangeAction.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline RemoteContentProviderChangeEvent::RemoteContentProviderChangeEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Identifier()
    , Action(::com::sun::star::ucb::RemoteContentProviderChangeAction_ADDED)
{
}

inline RemoteContentProviderChangeEvent::RemoteContentProviderChangeEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::rtl::OUString& Identifier_, const ::com::sun::star::ucb::RemoteContentProviderChangeAction& Action_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Identifier(Identifier_)
    , Action(Action_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::RemoteContentProviderChangeEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.ucb.RemoteContentProviderChangeEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/RemoteContentProviderChangeEvent.hpp <==
#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_
#define _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HDL_
#include "com/sun/star/ucb/RemoteContentProviderChangeEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEACTION_HPP_
#include "com/sun/star/ucb/RemoteContentProviderChangeAction.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline RemoteContentProviderChangeEvent::RemoteContentProviderChangeEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Identifier()
    , Action(::com::sun::star::ucb::RemoteContentProviderChangeAction_ADDED)
{
}

inline RemoteContentProviderChangeEvent::RemoteContentProviderChangeEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::rtl::OUString& Identifier_, const ::com::sun::star::ucb::RemoteContentProviderChangeAction& Action_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Identifier(Identifier_)
    , Action(Action_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::RemoteContentProviderChangeEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.ucb.RemoteContentProviderChangeEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::RemoteContentProviderChangeEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::ucb::RemoteContentProviderChangeEvent >::get();
}

#endif // _COM_SUN_STAR_UCB_REMOTECONTENTPROVIDERCHANGEEVENT_HPP_
